# Further reading

## Culbreth, G., Baxley, J. and Lambert, D., 2023

Culbreth, G., Baxley, J. and Lambert, D., 2023. Detecting temporal scaling with modified diffusion entropy analysis. _arXiv preprint arXiv:[2311.11453](https://arxiv.org/abs/2311.11453)_

## Culbreth, G., West, B.J. and Grigolini, P., 2019

Culbreth, G., West, B.J. and Grigolini, P., 2019. Entropic approach to the detection of crucial events. _Entropy, 21_(2), p.178. doi:[10.3390/e21020178](https://doi.org/10.3390/e21020178)

!!! note

    - This paper introduced the stripes and describes their role with figure examples.
    - This paper used $\eta$ to denote scaling, rather than $\delta$.

## Scafetta, N. and Grigolini, P., 2002

Scafetta, N. and Grigolini, P., 2002. Scaling detection in time series: Diffusion entropy analysis. _Physical Review E, 66_(3), p.036130. doi:[10.1103/PhysRevE.66.036130](https://doi.org/10.1103/PhysRevE.66.036130)

!!! note

    The actual algorithm for DEA is detailed (mostly only in words) in Section IV.

## Grigolini, P., Palatella, L. and Raffaelli, G., 2001

Grigolini, P., Palatella, L. and Raffaelli, G., 2001. Asymmetric anomalous diffusion: an efficient way to detect memory in time series. _Fractals, 9_(04), pp.439-449. doi:[10.1142/S0218348X01000865](https://doi.org/10.1142/S0218348X01000865)

!!! note

    This paper introduced always using positive steps when constructing the event array, rather than the sign of the step at that time index.
